@@ -28,6 +28,8 @@
 #include <config.h>
 #include "nautilus-bonobo-extensions.h"
 
+#include "nautilus-icon-factory.h"
+
 #include <eel/eel-string.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-debug.h>
@@ -487,6 +489,165 @@ nautilus_bonobo_set_label_for_toolitem_and_command (BonoboUIComponent *ui,
 	g_free (label_no_underscore);
 }
 
+static char *
+get_extension_menu_item_xml (NautilusMenuItem *item)
+{
+	GString *ui_xml;
+	char *pixbuf_data;
+	GdkPixbuf *pixbuf;
+	char *name;
+	char *icon;
+	
+	ui_xml = g_string_new ("");
+
+	g_object_get (G_OBJECT (item), "name", &name, "icon", &icon, NULL);
+
+	g_string_append_printf (ui_xml,
+				"<menuitem name=\"%s\" verb=\"%s\"",
+				name, name);
+	
+	if (icon) {
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name 
+			(icon,
+			 NULL,
+			 NAUTILUS_ICON_SIZE_FOR_MENUS,
+			 NULL);
+		if (pixbuf) {
+			pixbuf_data = bonobo_ui_util_pixbuf_to_xml (pixbuf);
+			g_string_append_printf (ui_xml, " pixtype=\"pixbuf\" pixname=\"%s\"", pixbuf_data);
+			g_free (pixbuf_data);
+			g_object_unref (pixbuf);
+		}
+	}
+	g_string_append (ui_xml, "/>");
+
+	g_free (name);
+	g_free (icon);
+
+	return g_string_free (ui_xml, FALSE);
+}
+
+static void
+extension_action_callback (BonoboUIComponent *component,
+			   gpointer callback_data, const char *path)
+{
+	nautilus_menu_item_activate (NAUTILUS_MENU_ITEM (callback_data));
+}
+
+void
+nautilus_bonobo_add_extension_item_command (BonoboUIComponent *ui,
+					    NautilusMenuItem *item)
+{
+	GString *ui_xml;
+	GClosure *closure;
+	char *name;
+	char *label;
+	char *tip;
+	char *sensitive;
+
+	ui_xml = g_string_new ("<Root><commands>");
+
+	g_object_get (G_OBJECT (item), 
+		      "name", &name, "label", &label, 
+		      "tip", &tip, "sensitive", &sensitive,
+		      NULL);
+
+	g_string_append_printf (ui_xml, 
+				"<cmd name=\"%s\" label=\"%s\" tip=\"%s\" sensitive=\"%s\"/>", 
+				name, label, tip, sensitive ? "1" : "0");
+
+	ui_xml = g_string_append (ui_xml, "</commands></Root>");
+	
+	bonobo_ui_component_set (ui, "/", ui_xml->str, NULL);
+	g_string_free (ui_xml, TRUE);
+
+
+	closure = g_cclosure_new
+		(G_CALLBACK (extension_action_callback),
+		 g_object_ref (item),
+		 (GClosureNotify)g_object_unref);
+	
+	bonobo_ui_component_add_verb_full (ui, name, closure);
+
+	g_free (name);
+	g_free (label);
+	g_free (tip);
+}
+
+void 
+nautilus_bonobo_add_extension_item (BonoboUIComponent *ui,
+				    const char *path,
+				    NautilusMenuItem *item)
+{
+	char *item_xml;
+
+	item_xml = get_extension_menu_item_xml (item);
+	
+	bonobo_ui_component_set (ui, path, item_xml, NULL);
+
+	g_free (item_xml);
+}
+
+static char *
+get_extension_toolbar_item_xml (NautilusMenuItem *item)
+{
+	GString *ui_xml;
+	char *pixbuf_data;
+	GdkPixbuf *pixbuf;
+	char *name;
+	char *icon;
+	gboolean priority;
+	
+	ui_xml = g_string_new ("");
+
+
+	g_object_get (item, 
+		      "name", &name, "priority", &priority, 
+		      "icon", &icon,
+		      NULL);
+	g_string_append_printf (ui_xml,
+				"<toolitem name=\"%s\" verb=\"%s\"",
+				name, name);
+
+	if (priority) {
+		g_string_append (ui_xml, " priority=\"1\"");
+	}
+
+	if (icon) {
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name 
+			(icon,
+			 NULL,
+			 NAUTILUS_ICON_SIZE_FOR_MENUS,
+			 NULL);
+		if (pixbuf) {
+			pixbuf_data = bonobo_ui_util_pixbuf_to_xml (pixbuf);
+			g_string_append_printf (ui_xml, " pixtype=\"pixbuf\" pixname=\"%s\"", pixbuf_data);
+			g_free (pixbuf_data);
+			g_object_unref (pixbuf);
+		}
+	}
+	g_string_append (ui_xml, "/>");
+
+	g_free (name);
+	g_free (icon);
+
+	return g_string_free (ui_xml, FALSE);
+}
+
+void 
+nautilus_bonobo_add_extension_toolbar_item (BonoboUIComponent *ui,
+					    const char *path,
+					    NautilusMenuItem *item)
+{
+	char *item_xml;
+
+	item_xml = get_extension_toolbar_item_xml (item);
+	
+	bonobo_ui_component_set (ui, path, item_xml, NULL);
+
+	g_free (item_xml);
+}
+
 static void
 activation_handle_done (NautilusBonoboActivationHandle *handle)
 {
