@@ -44,7 +44,6 @@
 #include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
-#include <eel/eel-generous-bin.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
@@ -222,12 +221,8 @@ ui_idle_handler (gpointer data)
 	old_updating_bonobo_state = window->details->updating_bonobo_state;
 
 	if (window->details->ui_pending_initialize_menus_part_2) {
-#if !NEW_UI_COMPLETE
-		if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
-			nautilus_navigation_window_initialize_menus_part_2 (NAUTILUS_NAVIGATION_WINDOW (window));
-		}
-#endif
-		window->details->ui_pending_initialize_menus_part_2 = FALSE;
+		EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+				 merge_menus_2, (window));
 	}
 
 	if (window->details->ui_is_frozen) {
@@ -432,19 +427,6 @@ nautilus_window_allow_reload (NautilusWindow *window, gboolean allow)
 	nautilus_window_ui_thaw (window);
 }
 
-void
-nautilus_window_allow_burn_cd (NautilusWindow *window, gboolean allow)
-{
-        g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-
-	nautilus_window_ui_freeze (window);
-
-        nautilus_bonobo_set_hidden (window->details->shell_ui,
-				    NAUTILUS_COMMAND_BURN_CD, !allow);
-
-	nautilus_window_ui_thaw (window);
-}
-
 void
 nautilus_window_go_home (NautilusWindow *window)
 {
@@ -469,26 +451,6 @@ nautilus_window_go_home (NautilusWindow *window)
 	g_free (home_uri);
 }
 
-void
-nautilus_window_launch_cd_burner (NautilusWindow *window)	
-{
-	GError *error;
-	char *argv[] = { "nautilus-cd-burner", NULL};
-
-	error = NULL;
-	if (!g_spawn_async (NULL,
-			    argv, NULL,
-			    G_SPAWN_SEARCH_PATH,
-			    NULL, NULL,
-			    NULL,
-			    &error)) {
-		eel_show_error_dialog (_("Unable to launch the cd burner application."), error->message,
-				       _("Can't Launch CD Burner"),
-				       GTK_WINDOW (window));
-		g_error_free (error);
-	}
-}
-
 void
 nautilus_window_prompt_for_location (NautilusWindow *window)
 {
@@ -621,6 +583,12 @@ real_merge_menus (NautilusWindow *window)
 	window->details->ui_pending_initialize_menus_part_2 = TRUE;
 }
 
+static void
+real_merge_menus_2 (NautilusWindow *window)
+{
+	window->details->ui_pending_initialize_menus_part_2 = FALSE;
+}
+
 static void
 nautilus_window_constructed (NautilusWindow *window)
 {
@@ -632,7 +600,6 @@ nautilus_window_constructed (NautilusWindow *window)
 			 merge_menus, (window));
 
 	nautilus_window_allow_stop (window, FALSE);
-	nautilus_window_allow_burn_cd (window, FALSE);
 
 	/* Set up undo manager */
 	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));	
@@ -1161,28 +1128,42 @@ nautilus_window_display_error (NautilusWindow *window, const char *error_msg)
 	gtk_widget_show (dialog);
 }
 
+static gboolean 
+is_method_root (char *uri)
+{
+	while (*uri != 0) {
+		if (*uri == ':') {
+			break;
+		}
+		if (!g_ascii_isalpha (*uri)) {
+			return FALSE;
+		}
+		uri++;
+	}
+	return (strcmp (uri, "://") == 0 ||
+		strcmp (uri, ":///") == 0);
+}
+
 static char *
 compute_default_title (const char *text_uri)
 {
 	NautilusFile *file;
 	char *title;
 	char *canonical_uri;
+	char *colon;
 	
 	canonical_uri = eel_make_uri_canonical (text_uri);
 	
+	title = NULL;
 	if (canonical_uri == NULL) {
 		title = g_strdup ("");
-	} else if (strcmp (canonical_uri, "computer:///") == 0 ) {
-		title = g_strdup (_("Computer"));
-	} else if (strcmp (canonical_uri, "network:///") == 0 ) {
-		title = g_strdup (_("Network"));
-	} else if (strcmp (canonical_uri, "fonts:///") == 0 ) {
-		title = g_strdup (_("Fonts"));
-	} else if (strcmp (canonical_uri, "themes:///") == 0 ) {
-		title = g_strdup (_("Themes"));
-	} else if (strcmp (canonical_uri, "burn:///") == 0 ) {
-		title = g_strdup (_("CD Creator"));
-	} else {
+	} else if (is_method_root (canonical_uri)) {
+		colon = strchr (canonical_uri, ':');
+		g_assert (colon != NULL);
+		*colon = 0;
+		title = g_strdup (nautilus_get_vfs_method_display_name (canonical_uri));
+	} 
+	if (title == NULL) {
 		file = nautilus_file_get (text_uri);
 		title = nautilus_file_get_display_name (file);
 		nautilus_file_unref (file);
@@ -1615,6 +1596,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	class->get_title = real_get_title;
 	class->set_title = real_set_title;
 	class->merge_menus = real_merge_menus;
+	class->merge_menus_2 = real_merge_menus_2;
 	class->set_content_view_widget = real_set_content_view_widget;
 	class->load_view_as_menu = real_load_view_as_menu;
 	
